"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const Server_1 = require("./Server");
const decorators_1 = require("./decorators");
const tmp = require("tmp");
const fs = require("fs-extra");
const path = require("path");
let StartService = class StartService {
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.started = true;
        });
    }
};
__decorate([
    decorators_1.Start(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], StartService.prototype, "start", null);
StartService = __decorate([
    decorators_1.BaseRoute('/start'),
    decorators_1.ServiceName('start')
], StartService);
describe('Server', function () {
    let server;
    let tmpDir;
    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
        tmpDir = tmp.dirSync();
        Realm.clearTestState();
        server = new Server_1.Server({ dataPath: tmpDir.name });
    }));
    afterEach(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        if (server) {
            yield server.shutdown();
        }
    }));
    it('should start by default with no services', function () {
        return __awaiter(this, void 0, void 0, function* () {
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(0);
        });
    });
    it('should allow skipping autokeygen', function () {
        return __awaiter(this, void 0, void 0, function* () {
            server.config.autoKeyGen = false;
            yield server.start();
            chai_1.assert.isFalse(fs.existsSync(path.resolve(server.config.dataPath, "keys", "auth.pub")));
            chai_1.assert.isFalse(fs.existsSync(path.resolve(server.config.dataPath, "keys", "auth.key")));
        });
    });
    it('should be able to add a new service', function () {
        return __awaiter(this, void 0, void 0, function* () {
            server.addService(new StartService());
            yield server.start();
            chai_1.expect(server.services.find(service => service instanceof StartService)).to.be.a('object');
            chai_1.expect(server.services.length).to.be.eq(1);
        });
    });
    it('should be able to add an array of services with one method: addServices', function () {
        return __awaiter(this, void 0, void 0, function* () {
            server.addServices(new StartService(), new StartService(), new StartService());
            yield server.start();
            chai_1.expect(server.services.find(service => service instanceof StartService)).to.be.a('object');
            chai_1.expect(server.services.length).to.be.eq(3);
        });
    });
    it('should be able to remove a service by name', function () {
        return __awaiter(this, void 0, void 0, function* () {
            server.addService(new StartService());
            chai_1.expect(server.services.length).to.be.eq(1);
            server.removeService('start');
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(0);
        });
    });
    it('should be able to remove a service by instance', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const startService = new StartService();
            server.addService(startService);
            chai_1.expect(server.services.length).to.be.eq(1);
            server.removeService(startService);
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(0);
        });
    });
});
//# sourceMappingURL=Server.spec.js.map