"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const sinon = require("sinon");
const chai = require("chai");
chai.use(require("chai-as-promised"));
const SyncProxyService_1 = require("./SyncProxyService");
describe('SyncProxyService', () => {
    let service;
    let discovery;
    beforeEach(() => {
        discovery = sinon.stub();
        service = new SyncProxyService_1.SyncProxyService();
    });
    function runHandler(service, req) {
        return __awaiter(this, void 0, void 0, function* () {
            const socket = sinon.stub();
            const head = sinon.stub();
            yield service.websocketHandler(req, socket, head);
        });
    }
    describe("websocketHandler", () => {
        describe("without an authorization header", () => {
            it("should reject with an error", () => __awaiter(this, void 0, void 0, function* () {
                yield chai_1.assert.isRejected(runHandler(service, {
                    headers: {},
                }), "Authorization header was not provided");
            }));
        });
        describe("with an invalid access token header", () => {
            it("should reject with an error", () => __awaiter(this, void 0, void 0, function* () {
                yield chai_1.assert.isRejected(runHandler(service, {
                    headers: {
                        'authorization': "gibberish",
                    },
                }), "Authorization header is not in a valid format");
            }));
        });
    });
});
//# sourceMappingURL=SyncProxyService.spec.js.map